| Title: | Data for Sunlight Spectra |
|---|---|
| Description: | Data for the extraterrestrial solar spectral irradiance and ground level solar spectral irradiance and irradiance. In addition data for shade light under vegetation and irradiance time series from different broadband sensors. Part of the 'r4photobiology' suite, Aphalo P. J. (2015) <doi:10.19232/uv4pb.2015.1.14>. |
| Authors: | Pedro J. Aphalo [aut, trl, cre] (ORCID: <https://orcid.org/0000-0003-3385-972X>), T. Matthew Robson [ctb] (ORCID: <https://orcid.org/0000-0002-8631-796X>), Saara M. Hartiakinen [ctb] (ORCID: <https://orcid.org/0000-0002-8430-6861>), Anders Lindfors [ctb], Titta K. Kotilainen [ctb] (ORCID: <https://orcid.org/0000-0002-2822-9734>) |
| Maintainer: | Pedro J. Aphalo <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.5.1.9000 |
| Built: | 2026-05-23 08:54:45 UTC |
| Source: | https://github.com/aphalo/photobiologySun |
Data for the extraterrestrial solar spectral irradiance and ground level solar spectral irradiance and irradiance. In addition data for shade light under vegetation and irradiance time series from different broadband sensors. Part of the 'r4photobiology' suite, Aphalo P. J. (2015) doi:10.19232/uv4pb.2015.1.14.
Maintainer: Pedro J. Aphalo [email protected] (ORCID) [translator]
Other contributors:
T. Matthew Robson (ORCID) [contributor]
Saara M. Hartiakinen (ORCID) [contributor]
Anders Lindfors [contributor]
Titta K. Kotilainen (ORCID) [contributor]
Aphalo, P. J., Albert, A., Björn, L. O., McLeod, A. R., Robson, T. M., Rosenqvist, E. (Eds.). (2012). Beyond the Visible: A handbook of best practice in plant UV photobiology (1st ed., p. xxx + 174). Helsinki: University of Helsinki, Department of Biosciences, Division of Plant Biology. ISBN 978-952-10-8363-1 (PDF), 978-952-10-8362-4 (paperback). Open access PDF download available at https://hdl.handle.net/10138/37558
Aphalo, Pedro J. (2015) The r4photobiology suite. UV4Plants Bulletin, 2015:1, 21-29. doi:10.19232/uv4pb.2015.1.14.
Useful links:
Report bugs at https://github.com/aphalo/photobiologySun/issues
library(photobiology) library(photobiologyWavebands) q_irrad(sun_may_morning.spct, PAR()) q_ratio(sun_may_morning.spct, Red("Smith10"), Far_red("Smith10"))library(photobiology) library(photobiologyWavebands) q_irrad(sun_may_morning.spct, PAR()) q_ratio(sun_may_morning.spct, Red("Smith10"), Far_red("Smith10"))
Dataset containing mean values for observed terrestrial radiation for PAR, UV-B, UV-A2, UV-A1, blue, red, and far-red photon irradiances and global radiation energy irradiance. Values are summaries of 12 consecutive readings acquired once every 5 s. The data set covers 4 consecutive days with different cloud conditions.
four_days_1min.datafour_days_1min.data
A data frame with 24479 rows and 9 variables. variables.
The variables are as follows:
time_EEST POSIXct Local time according to EET coordinates.
UTC POSIXct Local time according to UTC.
solar_time numeric Local solar time (h)
sun_elevation numeric Sun elevation above the astronomical horizon (degrees)
PAR_umo numeric (umol m-2 m-2)
PAR_diff_fr numeric Fraction of total downwelling PAR that is diffuse (/1)
global_watt numeric Global radiation (W m-2)
red_umol numeric Red () light (umol m-2 m-2)
far_red_umol numeric Far red () light (umol m-2 m-2)
blue_umol numeric blue light () (umol m-2 m-2)
blue_sellaro_umol numeric blue light () (umol m-2 m-2)
UVA_umol numeric UV-A radiation (315-400 nm) (umol m-2 m-2)
UVA1_umol numeric UV-A1 radiation (340-400 nm) (umol m-2 m-2)
UVA2_umol numeric UV-A2 radiation (315-340 nm) (umol m-2 m-2)
UVB_umol numeric UV-B radiation (280-315 nm) (umol m-2 m-2)
solar_disk factor Estimate of whether the solar disk was visible or occluded (visible, occluded)
These data are part of a much larger data set (Aphalo, 2023). height. Data collected with a Campbell Scientific CR6 datalogger, using analogue outputs from the sensors. Location: Viikki campus of the University of Helsinki. Coordinates: 60.226803 N, 25.019205 E. Same data were plotted in Fig. 1 of Sellaro et al. (2024).
Aphalo, Pedro J. (2023) High frequency weather data for Viikki, Helsinki, Finland. doi:10.17605/OSF.IO/E4VAU.
Sellaro, Romina; Durand, Maaxime; Aphalo, Pedro J., Casal, Jorge J. (2024) Making the most of canopy light: shade avoidance under a fluctuating spectrum and irradiance. Journal of Experimental Botany, erae334. doi:10.1093/jxb/erae334.
colnames(four_days_1min.data) nrow(four_days_1min.data) range(four_days_1min.data$time_EET) where_measured(four_days_1min.data) how_measured(four_days_1min.data) what_measured(four_days_1min.data) comment(four_days_1min.data)colnames(four_days_1min.data) nrow(four_days_1min.data) range(four_days_1min.data$time_EET) where_measured(four_days_1min.data) how_measured(four_days_1min.data) what_measured(four_days_1min.data) comment(four_days_1min.data)
A dataset containing a sequence of 72 spectra measured with an Ocean Optics Maya2000 Pro spectrometer and a Bentham DH-7-SM cosine diffuser. Values measured on 30 April 2014, in the late morning, under clear sky conditions. The whole sequence was measured in 39 seconds in a sunfleck under young silver birch trees. Place: University of Helsinki, Viikki Campus, Finland. Coordinates: 60.227162 N, 25.019429 E. Calibration and corrections done with package MayaCalc using bracketing and noise reduction (with filter measurement) and method "sun". Algorithm and calibration data by Lasse Ylianttila (STUK, Helsinki, Finland).
gap.mspctgap.mspct
A source_mspct object containing a collection of 72
source_spct objects.
The variables are as follows:
w.length (nm), range 293 to 800 nm.
s.e.irrad (W m-2 nm-1)
T. Matthew Robson and Saara Hartikainen (data).
Ylianttila, L.; Visuri, R.; Huurto, L. & Jokela, K. (2005) Evaluation of a single-monochromator diode array spectroradiometer for sunbed UV-radiation measurements. Photochem Photobiol, 81, 333-341
length(gap.mspct) # number of spectra e_irrad(gap.mspct, attr2tb = "when.measured") what_measured(gap.mspct)[1:2, ] when_measured(gap.mspct)[1:6, ]length(gap.mspct) # number of spectra e_irrad(gap.mspct, attr2tb = "when.measured") what_measured(gap.mspct)[1:2, ] when_measured(gap.mspct)[1:6, ]
Dataset containing mean, maximum, minimum and standard deviation values for global radiation data expressed as (energy) irradiance. Values are summaries of 12 consecutive readings acquired once every 5 s. The data set covers 17 consecutive days.
irrad_Kipp.datairrad_Kipp.data
A data frame with 24479 rows and 5 variables. variables.
The variables are as follows:
time_EEST POSIXct Local time according to EET coordinates.
UTC POSIXct Local time according to UTC.
e_irrad_mean numeric (W m-2)
e_irrad_min numeric (W m-2)
e_irrad_max numeric (W m-2)
e_irrad_sd numeric (W m-2)
These data are part of a much larger data set (Aphalo, 2023). Instrument used: Kipp SMP3 smart pyranometer, factory calibrated, mounted on permanent tripod at approximately 2 m height. Data collected with a Campbell Scientific CR6 datalogger. Wavelength sensitivity range of the pyranometer is 300 nm to 2800 nm. Location: Viikki campus of the University of Helsinki. Coordinates: 60.226803 N, 25.019205 E.
Aphalo, Pedro J. (2023) High frequency weather data for Viikki, Helsinki, Finland. doi:10.17605/OSF.IO/E4VAU.
colnames(irrad_Kipp.data) nrow(irrad_Kipp.data) range(irrad_Kipp.data$time_EET) where_measured(irrad_Kipp.data) how_measured(irrad_Kipp.data) what_measured(irrad_Kipp.data) comment(irrad_Kipp.data)colnames(irrad_Kipp.data) nrow(irrad_Kipp.data) range(irrad_Kipp.data$time_EET) where_measured(irrad_Kipp.data) how_measured(irrad_Kipp.data) what_measured(irrad_Kipp.data) comment(irrad_Kipp.data)
Dataset containing mean, maximum, minimum and standard deviation values for total, direct and diffuse photosynthetically active radiation expressed as photon irradiance. Values are summaries of 12 consecutive readings acquired once every 5 s. The data set covers 17 consecutive days.
ppfd_BF.datappfd_BF.data
A data frame with 24479 rows and 9 variables.
The variables are as follows:
time_EEST POSIXct Local time according to EET coordinates.
UTC POSIXct Local time according to UTC.
ppfd_tot_mean numeric (umol m-2 m-2)
ppfd_tot_min numeric (umol m-2 m-2)
ppfd_tot_max numeric (umol m-2 m-2)
ppfd_tot_sd numeric (umol m-2 m-2)
ppfd_diff_mean numeric (umol m-2 m-2)
ppfd_diff_min numeric (umol m-2 m-2)
ppfd_diff_max numeric (umol m-2 m-2)
ppfd_diff_sd numeric (umol m-2 m-2)
These data are part of a much larger data set (Aphalo, 2023). Instrument used: Delta-T BF5 "quantum sensor" , mounted on tripod at approximately 2 m height. Data collected with a Campbell Scientific CR6 datalogger, using analogue outputs from the sensor. Wavelength sensitivity range of the quantum sensor is 400 nm to 700 nm, but response is not proportional to energy quanta across wavelengths. Sensor calibrated in site for sunlight. Location: Viikki campus of the University of Helsinki, Finland. Coordinates: 60.226803 N, 25.019205 E.
Aphalo, Pedro J. (2023) High frequency weather data for Viikki, Helsinki, Finland. doi:10.17605/OSF.IO/E4VAU.
https://delta-t.co.uk/ https://www.campbellsci.com/
colnames(ppfd_BF.data) nrow(ppfd_BF.data) range(ppfd_BF.data$time_EET) where_measured(ppfd_BF.data) how_measured(ppfd_BF.data) what_measured(ppfd_BF.data) comment(ppfd_BF.data)colnames(ppfd_BF.data) nrow(ppfd_BF.data) range(ppfd_BF.data$time_EET) where_measured(ppfd_BF.data) how_measured(ppfd_BF.data) what_measured(ppfd_BF.data) comment(ppfd_BF.data)
Dataset containing mean, maximum, minimum and standard deviation values for photosynthetically active radiation expressed as photon irradiance. Values are summaries of 12 consecutive readings acquired once every 5 s. The data set covers 17 consecutive days.
ppfd_LICOR.datappfd_LICOR.data
A data frame with 24479 rows and 5 variables.
The variables are as follows:
time_EEST POSIXct Local time according to EET coordinates.
UTC POSIXct Local time according to UTC.
ppfd_mean numeric (umol m-2 m-2)
ppfd_min numeric (umol m-2 m-2)
ppfd_max numeric (umol m-2 m-2)
ppfd_sd numeric (umol m-2 m-2)
These data are part of a much larger data set (Aphalo, 2023). Instrument used: LI-COR LI-190 quantum sensor, mounted on permanent tripod at approximately 2 m height. Data collected with a Campbell Scientific CR6 datalogger. Sensor connected through a LI-COR millivolt adaptor (604 ohm). Wavelength sensitivity range of the quantum sensor is 400 nm to 700 nm. Location: Viikki campus of the University of Helsinki. Coordinates: 60.226803 N, 25.019205 E.
Aphalo, Pedro J. (2023) High frequency weather data for Viikki, Helsinki, Finland. doi:10.17605/OSF.IO/E4VAU.
https://www.licor.com/env/ https://www.campbellsci.com/
colnames(ppfd_LICOR.data) nrow(ppfd_LICOR.data) range(ppfd_LICOR.data$time_EET) where_measured(ppfd_LICOR.data) how_measured(ppfd_LICOR.data) what_measured(ppfd_LICOR.data) comment(ppfd_LICOR.data)colnames(ppfd_LICOR.data) nrow(ppfd_LICOR.data) range(ppfd_LICOR.data$time_EET) where_measured(ppfd_LICOR.data) how_measured(ppfd_LICOR.data) what_measured(ppfd_LICOR.data) comment(ppfd_LICOR.data)
Datasets containing the wavelengths at 1.0 nm interval and tabulated values of spectral irradiance and its direct and diffuse components at different sun elevation angles under clear sky conditions.
sun_elevation.spctsun_elevation.spct
A source_spct containing 34 spectra in long form (290.5 nm to
699.5 nm at 1 nm interval) and 6 variables.
The variables are as follows:
w.length numeric (nm)
s.e.irrad numeric (W m-2 nm-1)
s.e.irrad.dir numeric (W m-2 nm-1)
s.e.irrad.diff.down numeric (W m-2 nm-1)
s.e.irrad.diff.up numeric (W m-2 nm-1)
sun.elevation factor with one level per spectrum
Pedro J. Aphalo (radiation transfer modelling with Quick TUV calculator, TUV 5.3)
Quick TUV calculator https://www.acom.ucar.edu/Models/TUV/Interactive_TUV/.
e_irrad(sun_elevation.spct) wl_range(sun_elevation.spct) what_measured(sun_elevation.spct) when_measured(sun_elevation.spct)[[1]] getMultipleWl(sun_elevation.spct) # number of spectra unique(sun_elevation.spct$sun.elevation)e_irrad(sun_elevation.spct) wl_range(sun_elevation.spct) what_measured(sun_elevation.spct) when_measured(sun_elevation.spct)[[1]] getMultipleWl(sun_elevation.spct) # number of spectra unique(sun_elevation.spct$sun.elevation)
Datasets containing the wavelengths at 1.0 nm interval and tabulated values of spectral irradiance for the sun for 21 and 22 August in Helsinki, Finland.
sun_hourly_august.spctsun_hourly_august.spct
A source_spct containing 31 spectra in long form (293 nm to
800 nm at 1 nm interval) and 4 variables w.length, s.e.irrad,
UTC, and spct.idx.
The variables are as follows:
w.length numeric (nm)
s.e.irrad numeric (W m-2 nm-1)
UTC POSIXct (UTC date and time)
spct.idx factor with one level per spectrum
The data set includes NAs for missing night-time spectral irradiance values.
The simualtion methods has been described in Lindfors et al. (2009).
Anders K. Lindfors (radiation transfer modelling)
Lindfors, A.; Heikkilä, A.; Kaurola, J.; Koskela, T. & Lakkala, K. (2009) Reconstruction of Solar Spectral Surface UV Irradiances Using Radiative Transfer Simulations. Photochemistry and Photobiology, 85: 1233-1239
e_irrad(sun_hourly_august.spct) cat(what_measured(sun_hourly_august.spct)) when_measured(sun_hourly_august.spct)[[1]] where_measured(sun_hourly_august.spct) wl_range(sun_hourly_august.spct) getMultipleWl(sun_hourly_august.spct) # number of spectrae_irrad(sun_hourly_august.spct) cat(what_measured(sun_hourly_august.spct)) when_measured(sun_hourly_august.spct)[[1]] where_measured(sun_hourly_august.spct) wl_range(sun_hourly_august.spct) getMultipleWl(sun_hourly_august.spct) # number of spectra
Datasets containing the wavelengths at 1.0 nm interval and tabulated values of spectral irradiance for the sun for 22 to 24 June 2010 in Helsinki, Finland.
sun_hourly_june.spctsun_hourly_june.spct
A source_spct containing 58 spectra in long form (293 nm to
800 nm at 1 nm interval) and 4 variables w.length, s.e.irrad,
UTC, and spct.idx.
The variables are as follows:
w.length numeric (nm)
s.e.irrad numeric (W m-2 nm-1)
UTC POSIXct (UTC date and time)
spct.idx factor with one level per spectrum
The data set includes NAs for missing night-time spectral irradiance values.
A summary of these data has been published in the article by Morales et al. (2013). The simulation methods has been described in Lindfors et al. (2009).
Anders K. Lindfors (radiation transfer modelling)
Morales, L. O.; Brosché, M.; Vainonen, J.; Jenkins, G. I.; Wargent, J. J.; Sipari, N.; Strid, A.; Lindfors, A. V.; Tegelberg, R. & Aphalo, P. J. (2013) Multiple roles for UV RESISTANCE LOCUS8 in regulating gene expression and metabolite accumulation in Arabidopsis under solar ultraviolet radiation. Plant Physiology, 161, 744-759
Lindfors, A.; Heikkilä, A.; Kaurola, J.; Koskela, T. & Lakkala, K. (2009) Reconstruction of Solar Spectral Surface UV Irradiances Using Radiative Transfer Simulations. Photochemistry and Photobiology, 85: 1233-1239
e_irrad(sun_hourly_june.spct) cat(what_measured(sun_hourly_june.spct)) when_measured(sun_hourly_june.spct)[[1]] where_measured(sun_hourly_june.spct) wl_range(sun_hourly_june.spct) getMultipleWl(sun_hourly_june.spct) # number of spectrae_irrad(sun_hourly_june.spct) cat(what_measured(sun_hourly_june.spct)) when_measured(sun_hourly_june.spct)[[1]] where_measured(sun_hourly_june.spct) wl_range(sun_hourly_june.spct) getMultipleWl(sun_hourly_june.spct) # number of spectra
Datasets containing the wavelengths at 1.0 nm interval and tabulated values of spectral irradiance for the sun for 21 May, at Jokioinen, Finland, under climatology-based mean ozone column and with a 20 'libradtran' assuming clear sky.
sun_hourly_ozone.spctsun_hourly_ozone.spct
A source_spct containing 32 spectra in long form (293 nm to
800 nm at 1 nm interval) and 6 variables.
The variables are as follows:
w.length numeric (nm).
s.e.irrad numeric (W m-2 nm-1).
UTC POSIXct (UTC date and time).
ozone Factor with two levels.
sun.elevation Angle above the astronomical horizon (degrees).
spct.idx factor with one level per spectrum.
The data set includes spectra for day-time, not 24 h.
The simulation methods has been described in Lindfors et al. (2009).
Anders K. Lindfors (radiation transfer modelling).
Lindfors, A.; Heikkilä, A.; Kaurola, J.; Koskela, T. & Lakkala, K. (2009) Reconstruction of Solar Spectral Surface UV Irradiances Using Radiative Transfer Simulations. Photochemistry and Photobiology, 85: 1233-1239
e_irrad(sun_hourly_ozone.spct) what_measured(sun_hourly_ozone.spct) when_measured(sun_hourly_ozone.spct)[[1]] where_measured(sun_hourly_ozone.spct) how_measured(sun_hourly_ozone.spct) wl_range(sun_hourly_ozone.spct) getMultipleWl(sun_hourly_ozone.spct) # number of spectrae_irrad(sun_hourly_ozone.spct) what_measured(sun_hourly_ozone.spct) when_measured(sun_hourly_ozone.spct)[[1]] where_measured(sun_hourly_ozone.spct) how_measured(sun_hourly_ozone.spct) wl_range(sun_hourly_ozone.spct) getMultipleWl(sun_hourly_ozone.spct) # number of spectra
Datasets containing the wavelengths at a 0.5 nm to 1.0 nm interval and tabulated values of measured spectral irradiance for the sun.
sun_may_morning.spctsun_may_morning.spct
A source_spct object with 1421 rows (250 nm to 899 nm,
variable step) and 2 variables.
The variables are as follows:
w.length numeric (nm)
s.e.irrad numeric (W m-2 nm-1)
Instrument used: Maya2000Pro scanning double monochromator spectroradiometer with a Bentham cosine corrected input optics. Recently calibrated at STUK. Date and time: 31 May 2013, 11:23 EEST. Place: University of Helsinki, Viikki Campus, Finland. Coordinates: 60.226183 N, 25.018302 E. Measurements done by Pedro J. Aphalo. Calibration and corrections done with package MayaCalc using bracketing and noise reduction (with filter measurement) and method "sun". Algorithm and calibration data by Lasse Ylianttila (STUK, Helsinki, Finland).
Ylianttila, L.; Visuri, R.; Huurto, L. & Jokela, K. (2005) Evaluation of a single-monochromator diode array spectroradiometer for sunbed UV-radiation measurements. Photochem Photobiol, 81, 333-341
sun_may_morning.spct what_measured(sun_may_morning.spct) when_measured(sun_may_morning.spct) where_measured(sun_may_morning.spct) wl_range(sun_may_morning.spct) e_irrad(sun_may_morning.spct)sun_may_morning.spct what_measured(sun_may_morning.spct) when_measured(sun_may_morning.spct) where_measured(sun_may_morning.spct) wl_range(sun_may_morning.spct) e_irrad(sun_may_morning.spct)
Dataset containing wavelengths and tabulated values for spectral irradiance for the sun both above the terrestrial atmosphere and at ground level under clear sky. The different spectra in this collection are from ASTM G173 standard and other published sources.
sun_reference.mspctsun_reference.mspct
A "source_mspct" object containing 5 "source_spct"
objects.
In each of the member spectra, the variables are as follows:
w.length (nm)
s.e.irrad (W m-2 nm-1)
The effect of the pass of solar radiation depends on the elevation angle of the sun above the horizon as it affects the distance light travels through the atmosphere. This frequently expressed as equivalent air mass. AM0 is used for extraterrestrial normal solar irradiance (its integral is called the solar constant). AM1 represents the terrestrial solar spectrum at sea level with the sun located at the zenith. AM1.5 is commonly used as a reference suitable for mid-latitudes. The AM0 spectrum changes very little with time, while AM1.5 being at ground level is dependent on the composition of the atmosphere and affected by water vapour and ozone concentrations as well as by particulate matter and ground surface optical properties.
Irradiance describes a flux of energy onto a plane. The plane is usually
located horizontally and receives light from the sun (direct radiation) and
from the sky (diffuse radiation). Global radiation is the sum of direct and
diffuse. A variation is to quantity direct radiation separately from
diffuse radiation on a plane normal to the direction of the sun, called
direct normal irradiance. Independently of the units used in the sources
of the data, all these data are stored with wavelengths expressed in
nanometres and spectral energy irradiances
.
The three different AM0 spectra differ mainly in the range of wavelengths they cover. The two AM1.5 spectra are for simulations for typical clear sky conditions at mid-latitudes and a sun elevation of 41.81 degrees.
ASTM.E490.AM0 is the mean extraterrestrial solar spectrum,
for air mass zero (AM0).
Gueymard.AM0 is Gueymard's (2004) extraterrestrial solar spectrum,
for air mass zero (AM0). Used as the basis for calculating the terrestrial
solar spectra defined by ASTM G173.
WMO.Wehrli.AM0 is Wehrli's (1985) extraterrestrial solar spectrum,
for air mass zero (AM0). Used the World Meteorological Organization (WMO).
ASTM.G173.global is global spectral irradiance for air mass 1.5
(AM1.5). Reference Spectrum Derived from SMARTS v. 2.9.2 for AM1.5. (solar
zenith angle 48.19)
ASTM.G173.direct is direct spectral irradiance for air mass 1.5
(AM1.5). Reference Spectrum Derived from SMARTS v. 2.9.2 for AM1.5. (solar
zenith angle 48.19)
Metadata are stored as attributes in each of these spectral data objects
and can be accessed with methods
what_measured(),
how_measured() and comment().
https://rredc.nrel.gov/solar/spectra/am1.5/ (no longer on-line).
ASTM (2012) ASTM G173 Standard Tables for Reference Solar Spectral Irradiances: Direct Normal and Hemispherical on 37 degrees Tilted Surface.
Gueymard, C. A. (2004) The sun's total and spectral irradiance for solar energy applications and solar radiation models. Solar Energy, 76, 423-453. doi:j.solener.2003.08.039.
Wehrli, C. (1985) Extraterrestrial solar spectrum. Pub. No. 615, World Radiation Center, Davos, Switzerland.
summary(sun_reference.mspct) what_measured(sun_reference.mspct)summary(sun_reference.mspct) what_measured(sun_reference.mspct)